Function get_run_lock

pub fn get_run_lock(
    conf: &RunConfig,
) -> Result<StandaloneExclusiveFileLock, GetRunLockError>
Get the lock for the run action from evobench run, to ensure only one is ever executed at the same time.