Function open_queue_change_signals

pub fn open_queue_change_signals(
    global_app_state_dir: &GlobalAppStateDir,
) -> Result<SharedPollingSignals>
This instance is used to signal changes from the run daemon to the part(s) that regenerate output status files (HTML files) (currently also within the run daemon, but might change). Everything relevant to generate the evobench list view is sent to this.