pub enum Wd {
List {
terminal_table_opts: TerminalTableOpts,
active: bool,
error: bool,
numeric_sort: bool,
du_sort: bool,
id_only: bool,
no_du: bool,
no_commit: bool,
},
Cleanup {
dry_run: bool,
verbose: bool,
mode: WdCleanupMode,
},
Delete {
dry_run: bool,
force: bool,
verbose: bool,
allow_bare: WdAllowBareOpt,
ids: Vec<WorkingDirectoryIdOpt>,
},
Log(LogOrLogf),
Logf(LogOrLogf),
Mark {
allow_bare: WdAllowBareOpt,
ids: Vec<WorkingDirectoryIdOpt>,
},
Unmark {
allow_bare: WdAllowBareOpt,
ids: Vec<WorkingDirectoryIdOpt>,
},
Recycle {
allow_bare: WdAllowBareOpt,
ids: Vec<WorkingDirectoryIdOpt>,
},
Enter {
mark: bool,
unmark: bool,
force: bool,
no_fetch: bool,
allow_bare: WdAllowBareOpt,
id: WorkingDirectoryIdOpt,
},
}Variants
List
List the working directories; by default, show all of them
Fields
terminal_table_opts: TerminalTableOptsCleanup
Delete working directories that have been set aside due to errors
Fields
mode: WdCleanupModeWhich of the working directories with errors to delete
Delete
Immediately delete working directories
Fields
allow_bare: WdAllowBareOptids: Vec<WorkingDirectoryIdOpt>Which of the working directories in error status to
immediately delete. Refuses directories with different
status than error unless --force was given.
Log(LogOrLogf)
Open the log file for the last run in a working directory in
the PAGER (or less)
Logf(LogOrLogf)
Open the log file for the last run in a working directory in
tail -f.
Mark
Mark the given working directories for examination, so that
they are not deleted by evobench wd cleanup
Fields
allow_bare: WdAllowBareOptids: Vec<WorkingDirectoryIdOpt>The IDs of the working direcories to mark
Unmark
Change the status of the given working directories back to
“error”, so that they are again deleted by evobench wd cleanup
Fields
allow_bare: WdAllowBareOptids: Vec<WorkingDirectoryIdOpt>The IDs of the working direcories to unmark
Recycle
Change the status of the given working directories back to
“checkedout”, so that they can be used again by evobench run. (Be careful that you don’t recycle dirs with problems
that lead to errors again. It may be safer, albeit costlier,
to delete the dirs instead.)
Fields
allow_bare: WdAllowBareOptids: Vec<WorkingDirectoryIdOpt>The IDs of the working direcories to recycle
Enter
Mark the given working directory for examination, then open a
shell inside it. The shell in the SHELL environment variable
is used, falling back to “bash”.
Fields
mark: boolKeep the working directory marked for examination even after exiting the shell (default: ask interactively)
unmark: boolUnmark the working directory after exiting the shell (without asking, and even if the directory was marked)
no_fetch: boolDo not run git fetch --tags inside the working directory
(usually it’s a good idea to run it, to ensure the dataset
dir and COMMIT_TAGS are chosen based on up to date
remote data)
allow_bare: WdAllowBareOptid: WorkingDirectoryIdOptThe ID of the working directory to mark and enter
Implementations
Sourceimpl Wd
impl Wd
pub fn run( self, shareable_config: &ShareableConfig, working_directory_base_dir: &Arc<WorkingDirectoryPoolBaseDir>, queue_change_signals: PollingSignalsSender, ) -> Result<()>